@@ -2,6 +2,5 @@
 def zhangjie():
     print('hello')
 
-def hello()
+def hello():
     print('zhangjie')
-    
